@@ -142,9 +142,15 @@ class SearchPatchStateInstructionOp(hook.DataOperationMixIn,
             readycandidates = {}
             pendingcandidates = {}
             rejectcandidates = {}
-            for vc in rev.reverse_from_revision:
-                if not vc.patch:
+            done = set()
+            # consider both at_revision and from_revision since we want to be
+            # able to use magic instructions for files not touched by the
+            # revision (hence the at_revision), while DeletedVersionContent are
+            # not referenced by at_revision, only from_revision.
+            for vc in rev.reverse_at_revision + rev.reverse_from_revision:
+                if vc.eid in done or not vc.patch:
                     continue
+                done.add(vc.eid)
                 pstate = vc.patch.cw_adapt_to('IWorkflowable').state
                 if vc.__regid__ == 'VersionContent':
                     if pstate == 'in-progress':
@@ -189,7 +195,6 @@ class SearchPatchStateInstructionOp(hook.DataOperationMixIn,
                     # XXX search source repository changeset id
                     #patch.set_relations(applied_at=rev)
 
-
     def ensure_wont_be_deleted(self, patch):
         op = MarkPatchAsDeletedOp.get_instance(self.session)
         try:
