@@ -11,7 +11,7 @@ class PatchStatusChangeView(StatusChangeMixIn, NotificationView):
 
     def subject(self):
         entity = self.cw_rset.get_entity(0, 0)
-        return self._cw._(u'[patch %(state)s] %(patch)s (%(repo)s)') % {
+        return self._cw._(u'[%(repo)s] patch %(state)s: %(patch)s') % {
             'repo': entity.repository.dc_title(),
             'patch': entity.dc_title(),
             'state': self._cw.__(self._kwargs['current_state'])}
@@ -52,7 +52,7 @@ class TaskAddedView(task.TaskAddedView):
             patch = patch.parent.patch
             if not patch:
                 return super(TaskAddedView, self).subject()
-        return self._cw._(u'[patch task] %(patch)s: %(task)s (%(repo)s)') % {
+        return self._cw._(u'[%(repo)s] patch task: %(patch)s - %(task)s') % {
             'repo': patch.repository.dc_title(),
             'patch': patch.dc_title(),
             'task': entity.dc_title()}
@@ -75,7 +75,7 @@ url: %(url)s
 
     def subject(self):
         patch = self.cw_rset.get_entity(0, 0)
-        return self._cw._('[patch assigned] %(patch)s (%(repo)s)') % {
+        return self._cw._('[%(repo)s] patch assigned: %(patch)s') % {
             'app': self._cw.vreg.config.appid,
             'repo': patch.repository.dc_title(),
             'patch': patch.dc_title()}
