@@ -48,4 +48,8 @@ class PatchBranchFacet(facet.AttributeFacet):
     rtype = 'branch'
     i18nable = False
 
-
+class PatchCommitterFacet(facet.RelationFacet):
+    __regid__ = 'vcreview.patch_committer'
+    rtype = 'patch_committer'
+    role = 'subject'
+    target_attr = 'login'
